.. all-saltext.transactional-update.executors:

________________
Executor Modules
________________

.. currentmodule:: saltext.transactional_update.executors

.. autosummary::
    :toctree:

    transactional_update
